@@ -1,7 +1,13 @@
 // spell-checker:ignore getconf
 
 use std::fmt::{self, Display, Formatter};
-#[cfg(any(target_os = "linux", target_os = "freebsd", target_os = "macos"))]
+#[cfg(any(
+    target_os = "dragonfly",
+    target_os = "freebsd",
+    target_os = "linux",
+    target_os = "macos",
+    target_os = "netbsd"
+))]
 use std::process::{Command, Output};
 
 /// Operating system architecture in terms of how many bits compose the basic values it can deal with.
@@ -28,10 +34,11 @@ impl Display for Bitness {
 }
 
 #[cfg(any(
-    target_os = "linux",
-    target_os = "freebsd",
     target_os = "dragonfly",
-    target_os = "macos"
+    target_os = "freebsd",
+    target_os = "linux",
+    target_os = "macos",
+    target_os = "netbsd"
 ))]
 pub fn get() -> Bitness {
     match &Command::new("getconf").arg("LONG_BIT").output() {
@@ -43,7 +50,12 @@ pub fn get() -> Bitness {
 
 #[cfg(all(
     test,
-    any(target_os = "linux", target_os = "freebsd", target_os = "macos")
+    any(
+        target_os = "freebsd",
+        target_os = "linux",
+        target_os = "macos",
+        target_os = "netbsd"
+    )
 ))]
 mod tests {
     use super::*;
